@@ -1,168 +1,46 @@
 package Net::MovableType;
 
-# MovableType.pm,v 1.19 2004/08/25 02:49:28 sherzodr Exp
+# $Id: MovableType.pm,v 1.7 2003/07/27 12:12:36 sherzodr Exp $
 
 use strict;
 use vars qw($VERSION $errstr $errcode);
 use Carp;
 use XMLRPC::Lite;
 
-$VERSION = '1.75_01';
+($VERSION) = '$Revision: 1.7 $' =~ m/Revision:\s*(\S+)/;
 
 # Preloaded methods go here.
 
-
-sub _mk_boolean {
-    my $bool = shift;
-
-    return $bool if ref( $bool );
-    return SOAP::Data->type(boolean=>$bool || 0);
-}
-
-
-
 sub new {
-    my $class = shift;
-    $class = ref($class) || $class;
+  my $class = shift;
+  $class = ref($class) || $class;
+  my $self = {
+    _proxy => XMLRPC::Lite->proxy($_[0]),
+    username => $_[1],
+    password => $_[2]
+  };
 
-    my ($url, $username, $password) = @_;
-
-    my $self = {
-        proxy   => undef,
-        blogid   => undef,
-        username => $username,
-        password => $password
-    };
-
-    bless $self, $class;
-
-    # if $url starts with 'http://' and ends in '.xml', we assume it was a
-    # location of rsd.xml file
-    if ( $url =~ m/^http:\/\/.+\.xml$/ ) {
-        $self->rsd_url($url) or return undef;
-
-    # if the URL just starts with 'http://', we assume it was a url for
-    # MT's XML-RPC server
-    } elsif ( $url =~ m/^http:\/\// ) {
-        $self->{proxy} = XMLRPC::Lite->proxy($url);
-
-    # in neither case, we assume it was a file system location of rsd.xml file
-    } elsif ( $url ) {
-        $self->rsd_file($url) or return undef;
-    }
-
-    return $self;
+  return bless $self, $class
 }
 
 
 
 
 
-# shortcut for XMLRPC::Lite's call() method. Main difference from original call()
-# is, it returns native Perl data, instead of XMLRPC::SOM object
-sub call {
-    my ($self, $method, @args) = @_;
-
-    unless ( $method ) {
-        die "call(): usage error"
-    }
-
-    my $proxy = $self->{proxy} or die "'proxy' is missing";
-    my $som   = $proxy->call($method, @args);
-    my $result= $som->result();
-
-    unless ( defined $result ) {
-        $errstr = $som->faultstring;
-        $errcode= $som->faultcode;
-        return undef
-    }
-
-    return $result
-}
-
-
-
-
-sub process_rsd {
-    my ($self, $string_or_file ) = @_;
-
-    unless ( $string_or_file ) {
-        croak "process_rsd() usage error"
-    }
-
-    require XML::Simple;
-    my $xml     = XML::Simple::XMLin(ref($string_or_file) ? $$string_or_file : $string_or_file );
-    my $apilink = $xml->{service}->{apis}->{api}->{MetaWeblog}->{apiLink};
-    my $blogid  = $xml->{service}->{apis}->{api}->{MetaWeblog}->{blogID};
-
-    unless ( $apilink && $blogid ) {
-        croak "Couldn't retrieve 'apiLink' and 'blogID' from $xml"
-    }
-
-    $self->blogId($blogid);
-    $self->{proxy} = XMLRPC::Lite->proxy($apilink);
-
-    # need to return a true value indicating success
-    return 1
-}
-
-
-# fetches RSD file from a remote location,
-# and configures Net::MovableType object properly
-sub rsd_url {
-    my ($self, $url) = @_;
-
-    unless ( $url ) {
-        croak "rsd_url() usage error"
-    }
-
-    $self->{rsd_url} = $url;
-
-    require LWP::UserAgent;
-
-    my $ua = LWP::UserAgent->new();
-    my $req= HTTP::Request->new('GET', $url);
-    my $response = $ua->request($req);
-    if ( $response->is_error ) {
-        $errstr = $response->base . ": " . $response->message;
-        $errcode= $response->code;
-        return undef
-    }
-
-    return $self->process_rsd($response->content_ref)
-}
-
-
-
-sub rsd_file {
-    my ($self, $file) = @_;
-
-    unless ( $file ) {
-        croak "rsd_file() usage error"
-    }
-
-    $self->{rsd_file} = $file;
-
-    return $self->process_rsd($file)
-}
-
-
-
-
 sub username {
-    my ($self, $username) = @_;
+  my ($self, $username) = @_;
 
-    if ( defined $username ) {
-        $self->{username} = $username;
-    }
-    return $self->{username}
+  if ( defined $username ) {
+    $self->{username} = $username;
+  }
+  return $self->{username}
 }
 
 
 
 *error = \&errstr;
 sub errstr {
-    return $errstr
+  return $errstr
 }
 
 
@@ -174,23 +52,12 @@ sub errcode {
 
 
 sub password {
-    my ($self, $password) = @_;
+  my ($self, $password) = @_;
 
-    if ( defined $password ) {
-        $self->{password} = $password
-    }
-    return $self->{password};
-}
-
-
-
-sub proxy {
-    my ($self, $proxy) = @_;
-
-    if ( defined $proxy ) {
-        $self->{proxy} = $proxy
-    }
-    return $self->{proxy}
+  if ( defined $password ) {
+    $self->{password} = $password
+  }
+  return $self->{password}
 }
 
 
@@ -228,28 +95,6 @@ sub resolveBlogId {
 
 
 
-sub getBlogInfo {
-    my ($self, $blogid) = @_;
-
-    $blogid ||= $self->blogId() or croak "no 'blogId' set";
-    my $blogs = $self->getUsersBlogs() or return undef;
-
-    while ( my $b = shift @$blogs ) {
-        if ( $b->{blogid} == $blogid ) {
-            return $b
-        }
-    }
-
-    $errstr = "No blog found with id '$blogid";
-    return undef
-}
-
-
-
-
-
-
-
 *getBlogs = \&getUsersBlogs;
 sub getUsersBlogs {
     my ($self, $username, $password)  = @_;
@@ -261,7 +106,16 @@ sub getUsersBlogs {
         croak "username and password are missing";
     }
 
-    return $self->call('blogger.getUsersBlogs', "", $username, $password)
+    my $proxy   = $self->{_proxy};
+    my $som     = $proxy->call('blogger.getUsersBlogs', "", $username, $password);
+    my $result  = $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstring;
+        $errcode = $som->faultcode;
+        return undef
+    }
+    return $result
 }
 
 
@@ -279,7 +133,17 @@ sub getUserInfo {
         croak "username and/or password are missing"
     }
 
-    return $self->call('blogger.getUserInfo', "", $username, $password)
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('blogger.getUserInfo', "", $username, $password);
+    my $result= $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstring;
+        $errcode= $som->faultcode;
+        return undef;
+    }
+
+    return $result
 }
 
 
@@ -295,7 +159,17 @@ sub getPost {
         croak "getPost() usage error"
     }
 
-    return $self->call('metaWeblog.getPost', $postid, $username, $password)
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('metaWeblog.getPost', $postid, $username, $password);
+    my $result= $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstring;
+        $errcode = $som->faultcode;
+        return undef
+    }
+
+    return $result
 }
 
 
@@ -312,7 +186,16 @@ sub getRecentPosts {
     my $password = $self->password()   or croak "no 'password' defined";
     $numposts ||= 1;
 
-    return $self->call('metaWeblog.getRecentPosts', $blogid, $username, $password, $numposts)
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('metaWeblog.getRecentPosts', $blogid, $username, $password, $numposts);
+    my $result= $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstring;
+        $errcode = $som->faultcode;
+        return undef
+    }
+    return $result
 }
 
 
@@ -325,7 +208,16 @@ sub getRecentPostTitles {
     my $password= $self->password()     or croak "no 'password' defined";
     $numposts ||= 1;
 
-    return $self->call('mt.getRecentPostTitles', $blogid, $username, $password, $numposts)
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('mt.getRecentPostTitles', $blogid, $username, $password, $numposts);
+    my $result= $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstring;
+        $errcode = $som->faultcode;
+        return undef
+    }
+    return $result
 }
 
 
@@ -341,7 +233,16 @@ sub getCategoryList {
     $username   = $self->username($username) or croak "no 'username' defined";
     $password   = $self->password($password) or croak "no 'password' defined";
 
-    return $self->call('mt.getCategoryList', $blogid, $username, $password)
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('mt.getCategoryList', $blogid, $username, $password);
+    my $result= $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstring;
+        $errcode = $som->faultcode;
+        return undef
+    }
+    return $result
 }
 
 
@@ -357,7 +258,16 @@ sub getPostCategories {
         croak "getPostCategories() usage error"
     }
 
-    return $self->call('mt.getPostCategories', $postid, $username, $password)
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('mt.getPostCategories', $postid, $username, $password);
+    my $result= $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultring();
+        $errcode= $som->faultcode();
+        return undef
+    }
+    return $result
 }
 
 
@@ -365,13 +275,12 @@ sub getPostCategories {
 sub setPostCategories {
     my ($self, $postid, $cats) = @_;
 
-    unless ( ref $cats ) {
-        $cats = [$cats]
-    }
-
     unless ( @$cats && $postid ) {
         croak "setPostCategories() usage error"
     }
+    unless ( ref $cats ) {
+        $cats = [$cats]
+    }
 
     my $blogid = $self->blogId()    or croak "no 'blogId' set";
 
@@ -389,7 +298,16 @@ sub setPostCategories {
     my $password  = $self->password() or croak "no 'password' defined";
     $postid                          or croak "setPostCategories() usage error";
 
-    return $self->call('mt.setPostCategories', $postid, $username, $password, $post_categories)
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('mt.setPostCategories', $postid, $username, $password, $post_categories);
+    my $result= $som->result;
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstring;
+        $errcode= $som->faultcode;
+        return undef
+    }
+    return $result
 }
 
 
@@ -405,7 +323,16 @@ sub setPostCategories {
 sub supportedMethods {
     my ($self) = @_;
 
-    return $self->call('mt.supportedMethods')
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('mt.supportedMethods');
+    my $result= $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstring;
+        $errcode= $som->faultcode;
+        return undef
+    }
+    return $result
 }
 
 
@@ -420,7 +347,16 @@ sub publishPost {
         croak "publishPost() usage error"
     }
 
-    return $self->call('mt.publishPost', $postid, $username, $password)
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('mt.publishPost', $postid, $username, $password);
+    my $result= $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultsring;
+        $errcode= $som->faultcode;
+        return undef
+    }
+    return $result
 }
 
 
@@ -429,7 +365,6 @@ sub publishPost {
 
 sub newPost {
     my ($self, $content, $publish) = @_;
-    $publish = _mk_boolean($publish);
 
     my $blogid   = $self->blogId()   or croak "'blogId' is missing";
     my $username = $self->username() or croak "'username' is not set";
@@ -439,7 +374,16 @@ sub newPost {
         croak "newPost() usage error"
     }
 
-    return $self->call('metaWeblog.newPost', $blogid, $username, $password, $content, $publish)
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('metaWeblog.newPost', $blogid, $username, $password, $content, $publish);
+    my $result = $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstring;
+        $errcode= $som->faultcode;
+        return undef
+    }
+    return $result
 }
 
 
@@ -449,7 +393,6 @@ sub newPost {
 
 sub editPost {
     my ($self, $postid, $content, $publish) = @_;
-    $publish = _mk_boolean($publish);
 
     my $username = $self->username() or croak "'username' is not set";
     my $password = $self->password() or croak "'password' is not set";
@@ -457,7 +400,17 @@ sub editPost {
     unless ( $content && (ref($content) eq 'HASH') ) {
         croak "newPost() usage error"
     }
-    return $self->call('metaWeblog.editPost', $postid, $username, $password, $content, $publish)
+
+    my $proxy = $self->{_proxy};
+    my $som   = $proxy->call('metaWeblog.editPost', $postid, $username, $password, $content, $publish);
+    my $result = $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstring;
+        $errcode= $som->faultcode;
+        return undef
+    }
+    return $result
 }
 
 
@@ -467,66 +420,26 @@ sub editPost {
 
 sub deletePost {
     my ($self, $postid, $publish) = @_;
-    $publish = _mk_boolean($publish);
 
     my $username = $self->username or croak "'username' not set";
     my $password = $self->password or croak "'password' not set";
     $postid                        or croak "deletePost() usage error";
 
-    return $self->call('blogger.deletePost', "", $postid, $username, $password, $publish)
+    my $proxy    = $self->{_proxy};
+    my $som      = $proxy->call('blogger.deletePost', "", $postid, $username, $password, $publish);
+    my $result   = $som->result();
+
+    unless ( defined $result ) {
+        $errstr = $som->faultstr;
+        $errcode= $som->faultcode;
+        return undef
+    }
+    return $result
 }
 
 
 
 
-*upload = \&newMediaObject;
-sub newMediaObject {
-    my ($self, $filename, $name, $type) = @_;
-
-    my $blogid   = $self->blogId()   or croak "'blogId' is missing";
-    my $username = $self->username() or croak "'username' is not set";
-    my $password = $self->password() or croak "'password' is not set";
-
-    unless ( $filename ) {
-        croak "newMediaObject() usage error";
-    }
-
-    my $blob = undef;
-    if ( ref $filename ) {
-        $blob = $$filename;
-        $filename = undef;
-
-    } else {
-        unless(open(FH, $filename)) {
-            $errstr = "couldn't open $filename: $!";
-            return undef
-        }
-        local $/ = undef;
-        $blob = <FH>; close(FH);
-    }
-
-    if ( $filename && !$name ) {
-        require File::Basename;
-        $name = File::Basename::basename($filename);
-    }
-
-    unless ( $name ) {
-        croak "newMediaObject() usage error: \$name is missing"
-    }
-
-    my %content_hash = (
-         bits    => XMLRPC::Data->type(base64 => $blob),
-         name    => $name,
-         type    => $type || ""
-    );
-
-    return $self->call('metaWeblog.newMediaObject', $blogid, $username, $password, \%content_hash)
-}
-
-
-
-
-
 
 
 
@@ -542,14 +455,6 @@ sub dump {
 
 
 
-package MovableType;
-@MovableType::ISA = ('Net::MovableType');
-
-
-package MT;
-@MT::ISA = ('Net::MovableType');
-
-
 1;
 __END__
 # Below is stub documentation for your module. You better edit it!
@@ -561,9 +466,10 @@ Net::MovableType - light-weight MovableType client
 =head1 SYNOPSIS
 
   use Net::MovableType;
-  my $mt = new Net::MovableType('http://your.com/rsd.xml');
+  my $mt = new Net::MovableType('http://mt.handalak.com/cgi-bin/xmlrpc');
   $mt->username('user');
   $mt->password('secret');
+  $mt->blogId(1);
 
   my $entries = $mt->getRecentPosts(5);
   while ( my $entry = shift @$entries ) {
@@ -573,18 +479,21 @@ Net::MovableType - light-weight MovableType client
 
 =head1 DESCRIPTION
 
+I<Net::MovableType> is a light-weight, XML-RPC based client for MovableType's entry database.
+It supports all of MovableType's remote procedures.
+
 Using I<Net::MovableType> you can post new entries, edit existing entries, browse entries
 and users blogs, and perform most of the features you can perform through accessing your
 MovableType account.
 
-Since I<Net::MovableType> uses MT's XML-RPC (I<Remote Procedure Call> gateway, you can do it from
-any computer with Internet connection.
+Since I<Net::MovableType> uses MT's I<remote procedure call> gateway, you can do it from
+any computer with an interface connection.
 
-=head1 PROGRAMMING STYLE
+=head1 PROGRAMMING INTERFACE
 
 I<Net::MovableType> promises an intuitive, user friendly, Object Oriented interface for managing
 your web sites published through MovableType. Most of the method names correspond to those documented
-in MovableType's Programming Interface Manual, however, their expected arguments differ.
+in MovableType's Programming Interface Manual.
 
 =head2 CREATING MT OBJECT
 
@@ -592,37 +501,21 @@ Before you start doing anything, you need to have a I<MovableType> object handy.
 create a I<MovableType> object by calling C<new()> - constructor method:
 
     $mt = new MovableType('http://mt.handalak.com/cgi-bin/mt-xmlrpc.cgi');
-    # or
-    $mt = new MovableType('http://author.handalak.com/rsd.xml');
-    # or even..
-    $mt = new MovableType('/home/sherzodr/public_html/author/rsd.xml');
 
 Notice, you need to pass at least one argument while creating I<MT> object, that is
-the location of your either F<mt-xmlrpc.cgi> file, or your web site's F<rsd.xml> file.
-Default templates of I<MT> already generate F<rsd.xml> file for you. If they don't,
-you should get one from http://www.movabletype.org/
-
-If your F<rsd.xml> file is available locally, you should provide a full path to the
-file instead of providing it as a URL. Reading the file locally is more efficient
-than fetching it over the Web.
-
-Giving it a location of your F<rsd.xml> file is preferred, since it will ensure that
-your C<blogId()> will be set properly. Otherwise, you will have to do it manually calling
-C<blogId()> (see later).
-
-It is very important that you get this one right. Otherwise, I<Net::MovableType> will
-know neither about where your web site is nor how to access them.
+the location of your "mt-xmlrpc.cgi". It is very important that you get this one right.
+Otherwise, I<Net::MovableType> will know neither about where your web sites are, and how to
+access them.
 
 I<MovableType> requires you to provide valid username/password pair to do most of the things.
 So you need to tell I<MovableType> object about your username and passwords, so it can use
 them to access the resources.
 
-=head2 LOGGING IN
-
 You can login in two ways; by either providing your I<username> and I<password> while creating
 I<MT> object, or by calling C<username()> and C<password()> methods after creating I<MT> object:
 
     # creating MT object with valid username/password:
+    $proxy = 'http://mt.handalak.com/cgi-bin/mt-xmlrpc.cgi';
     $mt = new MovableType($proxy, 'author', 'password');
 
     # or
@@ -630,22 +523,20 @@ I<MT> object, or by calling C<username()> and C<password()> methods after creati
     $mt->username('author');
     $mt->password('password');
 
+
 C<username()> and C<password()> methods are used for both setting username and password,
-as well as for retrieving username and password for the current user. Just don't pass
+as well as for retrieving username and password for the current logged in. Just don't pass
 it any arguments should you wish to use for the latter purpose.
 
 =head2 DEFINING A BLOG ID
 
-Defining a blog id may not be necessary if you generated your C<$mt> object
-with an F<rsd.xml> file. Otherwise, read on.
-
-As we will see in subsequent sections, most of the I<MovableType>'s methods operate on
+As we will see in subsequent sections, some of the I<MovableType>'s methods operate on
 specific web log. For defining a default web log to operate on, after setting above I<username>
 and I<password>, you can also set your default blog id using C<blogId()> method:
 
     $mt->blogId(1);
 
-To be able to do this, you first need to know your blog id. There are no documented ways of
+To be able to do that, you first need to know your blog id. There are no documented ways of
 retrieving your blog id, except for investigating the URL of your MovableType account panel.
 Just login to your MovableType control panel (through F<mt.cgi> script). In the first screen,
 you should see a list of your web logs. Click on the web log in question, and look at the
@@ -666,9 +557,9 @@ by calling C<getUsersBlogs()> method:
 
     $blogs = $mt->getUsersBlogs();
 
-C<getUsersBlogs()> returns list of blogs, where each blog is represented with a hashref. Each hashref
+C<getUsersBlogs()> returns list of blogs, where each blog is represented as a hashref. Each hashref
 holds such information as I<blogid>, I<blogName> and I<url>. Following example lists all the
-blogs belonging to the current user:
+blogs belonging to the current logged in user:
 
     $blogs = $mt->getUsersBlogs();
     for $b ( @$blogs ) {
@@ -677,7 +568,7 @@ blogs belonging to the current user:
 
 =head2 POSTING NEW ENTRY
 
-By now, you know how to login and how to define your blogId. Now is a good time to post
+By now, you know how to login and how to define your blog_id. Now is a good time to post
 a new article to your web log. That's what  C<newPost()> method is for.
 
 C<newPost()> expects at least a single argument, which should be a reference to a hash
@@ -853,64 +744,18 @@ ensures that your pages pertaining to the deleted entry are rebuilt:
 
     $mt->deletePost(122, 1); # <-- delet post 122, and rebuilt the web site
 
+=head2 ERROR HANDLING
 
-=head2 UPLOADING
-
-With I<Net::MovableType>, you can also upload files to your web site. Most common
-use of this feature is to associate an image, or some other downloadable file with
-your entries.
-
-I<Net::MovableType> provides C<upload()> method, which given a file contents,
-uploads it to your web site's F<archives> folder. On success, returns the URL of
-the newly uploaded file.
-
-C<upload()> method accepts either a full path to your file, or a reference to its
-contents. Second argument to upload() should be the file's name. If you already provided
-file's full path as the first argument, I<Net::MovableType> resolves the name of the file
-automatically, if it's missing.
-
-If you passed the contents of the file as the first argument, you are required to provide
-the name of the file explicitly.
-
-Consider the following code, which uploads a F<logo.gif> file to your web site:
-
-    $url = $mt->upload('D:\images\logo.gif');
-
-Following example uploads the same file, but saves it as "my-log.gif", instead of
-"logo.gif":
-
-    $url = $mt->upload('D:\images\logo.gif', 'my-logo.gif');
-
-Following example downloads a file from some remote location, using LWP::Simple,
-and uploads it to your web site with name "image.jpeg":
-
-    use LWP::Simple;
-
-    $content = get('http://some.dot.com/image.jpeg');
-    $url = $mt->upload( \$content, 'image.jpeg' )
-
-B<IMPORTANT NOTE:> above I<$url> returned from C<upload()> is a hashref, holding a single key, I<url>. 
-To print the URL out:
-
-    $url = $mt->upload(\$content, 'image.jpeg');
-    printf("File has been successfully uploaded to %s\n", $url->{url};
-
-It might've been easier for me to change the behavior of C<upload()> rather than making library's new users
-accept this unintuitive usage. By doing so I could've broken all applications relying on initial syntax.
-Backward-compatibility is more important than improvements on user interface.
-
-=head1 ERROR HANDLING
-
-If you noticed, we didn't even try to check if any of our remote procedure calls
+If you noticed, we didn't even try to check if eny of our remote procedure calls
 succeeded. This is to keep the examples as clean as possible.
 
-For example, consider the following call:
+For examlpe, consider the following call:
 
     $new_id = $mt->newPost($entry, 1);
 
-There is no guarantee that the above entry is posted, nor published.
+There is no guaranteed that the above entry will be posted, or published.
 You username/password might be wrong, or you made a mistake while defining your
-I<mt-xmlrpc> gateway? You may never know until its too late.
+I<mt-xmlrpc> gateway? You may never know untill its too late.
 
 That's why you should always check the return value of the methods that make a remote
 procedure call.
@@ -924,58 +769,14 @@ message (not always as useful) can be retrieved through C<errcode()> static clas
         die $mt->errstr
     }
 
-or just:
+or:
 
     $new_id = $mt->newPost($entry, 1) or die $mt->errstr;
 
-If you are creating your I<MovableType> object with an F<rsd.xml> file, you should also
-check the return value of C<new()>:
-
-    $mt = new Net::MovableType($rsd_url);
-    unless ( defined $mt ) {
-        die "couldn't create MT object with $rsd_url: " . Net::MovableType->errstr
-    }
-
-
-=head1 OTHER METHODS
-
-comming soon...
-
-=head1 TEST BLOG
-
-I opened a public test blog at http://net-mt.handalak.com/. Initial purpose of this
-blog was to provide a working weblog for Net::MovableType's tests to operate on. Currently
-its open to the World.
-
-Credentials needed for accessing this weblog through Net::MovableType are:
-
-    Username: net-mt
-    Password: secret
-
 =head1 TODO
 
 Should implement a caching mechanism
 
-Manual is still not complete, more methods are left to be documented properly
-
-
-=head1 CREDITS
-
-Following people have contributed to the library with their suggestions and patches,
-in chronological order. The list may not be complete.
-
-=over 4
-
-=item Atsushi Sano
-
-For F<rsd.xml> and C<newMediaObject()> support.
-
-=item Fredrik Acosta
-
-For fixing few bugs revealed while using Net::MovableType with WordPress.
-
-=back
-
 =head1 COPYRIGHT
 
 Copyright (C) 2003, Sherzod B. Ruzmetov. All rights reserved.
